pub struct JavaScriptEvaluationId(pub usize);Expand description
An identifier for a particular JavaScript evaluation that is used to track the evaluation from the embedding layer to the script layer and then back.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for JavaScriptEvaluationId
impl Clone for JavaScriptEvaluationId
Sourcefn clone(&self) -> JavaScriptEvaluationId
fn clone(&self) -> JavaScriptEvaluationId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for JavaScriptEvaluationId
Sourceimpl<'de> Deserialize<'de> for JavaScriptEvaluationId
impl<'de> Deserialize<'de> for JavaScriptEvaluationId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for JavaScriptEvaluationId
Sourceimpl Hash for JavaScriptEvaluationId
impl Hash for JavaScriptEvaluationId
Sourceimpl PartialEq for JavaScriptEvaluationId
impl PartialEq for JavaScriptEvaluationId
Sourcefn eq(&self, other: &JavaScriptEvaluationId) -> bool
fn eq(&self, other: &JavaScriptEvaluationId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for JavaScriptEvaluationId
impl Serialize for JavaScriptEvaluationId
impl StructuralPartialEq for JavaScriptEvaluationId